package com.doc.biz.controller;

import com.doc.biz.domain.DocMsg;
import com.doc.biz.service.IDocMsgService;
import com.doc.common.annotation.Log;
import com.doc.common.core.controller.BaseController;
import com.doc.common.core.domain.AjaxResult;
import com.doc.common.core.page.TableDataInfo;
import com.doc.common.enums.BusinessType;
import com.doc.common.utils.poi.ExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 消息管理Controller
 *
 * @author wukai
 * @date 2023-08-15
 */
@Api(tags = "消息管理")
@RestController
@RequestMapping("/biz/msg")
public class DocMsgController extends BaseController {
    @Resource
    private IDocMsgService docMsgService;

    /**
     * 查询消息管理列表
     */
    @ApiOperation("查询消息管理列表")
    //@PreAuthorize("@ss.hasPermi('biz:msg:list')")
    @GetMapping("/list")
    public TableDataInfo list(DocMsg docMsg) {
        startPage();
        List<DocMsg> list = docMsgService.selectDocMsgList(docMsg);
        return getDataTable(list);
    }

    /**
     * 导出消息管理列表
     */
    @ApiOperation("导出消息管理列表")
    //@PreAuthorize("@ss.hasPermi('biz:msg:export')")
    @Log(title = "消息管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DocMsg docMsg) {
        List<DocMsg> list = docMsgService.selectDocMsgList(docMsg);
        ExcelUtil<DocMsg> util = new ExcelUtil<DocMsg>(DocMsg.class);
        util.exportExcel(response, list, "消息管理数据");
    }

    /**
     * 获取消息管理详细信息
     */
    @ApiOperation("获取消息管理详细信息")
    //@PreAuthorize("@ss.hasPermi('biz:msg:query')")
    @GetMapping(value = "/{msgId}")
    public AjaxResult getInfo(@PathVariable("msgId") Long msgId) {
        return success(docMsgService.selectDocMsgByMsgId(msgId));
    }

    /**
     * 新增消息管理
     */
    @ApiOperation("新增消息管理")
    //@PreAuthorize("@ss.hasPermi('biz:msg:add')")
    @Log(title = "消息管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DocMsg docMsg) {
        return toAjax(docMsgService.insertDocMsg(docMsg));
    }

    /**
     * 修改消息管理
     */
    @ApiOperation("修改消息管理")
    //@PreAuthorize("@ss.hasPermi('biz:msg:edit')")
    @Log(title = "消息管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DocMsg docMsg) {
        return toAjax(docMsgService.updateDocMsg(docMsg));
    }

    /**
     * 删除消息管理
     */
    @ApiOperation("删除消息管理")
    //@PreAuthorize("@ss.hasPermi('biz:msg:remove')")
    @Log(title = "消息管理", businessType = BusinessType.DELETE)
    @DeleteMapping("/{msgIds}")
    public AjaxResult remove(@PathVariable Long[] msgIds) {
        return toAjax(docMsgService.deleteDocMsgByMsgIds(msgIds));
    }
}
