package com.doc.biz.service.impl;

import com.doc.biz.domain.DocMsg;
import com.doc.biz.mapper.DocMsgMapper;
import com.doc.biz.service.IDocMsgService;
import com.doc.common.utils.DateUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 消息管理Service业务层处理
 *
 * @author wukai
 * @date 2023-08-15
 */
@Service
public class DocMsgServiceImpl implements IDocMsgService {
    @Resource
    private DocMsgMapper docMsgMapper;

    /**
     * 查询消息管理
     *
     * @param msgId 消息管理主键
     * @return 消息管理
     */
    @Override
    public DocMsg selectDocMsgByMsgId(Long msgId) {
        return docMsgMapper.selectDocMsgByMsgId(msgId);
    }

    /**
     * 查询消息管理列表
     *
     * @param docMsg 消息管理
     * @return 消息管理
     */
    @Override
    public List<DocMsg> selectDocMsgList(DocMsg docMsg) {
        return docMsgMapper.selectDocMsgList(docMsg);
    }

    /**
     * 新增消息管理
     *
     * @param docMsg 消息管理
     * @return 结果
     */
    @Override
    public int insertDocMsg(DocMsg docMsg) {
        docMsg.setCreateTime(DateUtils.getNowDate());
        return docMsgMapper.insertDocMsg(docMsg);
    }

    /**
     * 修改消息管理
     *
     * @param docMsg 消息管理
     * @return 结果
     */
    @Override
    public int updateDocMsg(DocMsg docMsg) {
        docMsg.setUpdateTime(DateUtils.getNowDate());
        return docMsgMapper.updateDocMsg(docMsg);
    }

    /**
     * 批量删除消息管理
     *
     * @param msgIds 需要删除的消息管理主键
     * @return 结果
     */
    @Override
    public int deleteDocMsgByMsgIds(Long[] msgIds) {
        return docMsgMapper.deleteDocMsgByMsgIds(msgIds);
    }

    /**
     * 删除消息管理信息
     *
     * @param msgId 消息管理主键
     * @return 结果
     */
    @Override
    public int deleteDocMsgByMsgId(Long msgId) {
        return docMsgMapper.deleteDocMsgByMsgId(msgId);
    }
}
