package com.doc.biz.service.impl;

import com.doc.biz.domain.DocSpace;
import com.doc.biz.mapper.DocSpaceMapper;
import com.doc.biz.service.IDocSpaceService;
import com.doc.common.utils.DateUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 文档空间管理Service业务层处理
 *
 * @author wukai
 * @date 2023-08-15
 */
@Service
public class DocSpaceServiceImpl implements IDocSpaceService {
    @Resource
    private DocSpaceMapper docSpaceMapper;

    /**
     * 查询文档空间管理
     *
     * @param spaceId 文档空间管理主键
     * @return 文档空间管理
     */
    @Override
    public DocSpace selectDocSpaceBySpaceId(Long spaceId) {
        return docSpaceMapper.selectDocSpaceBySpaceId(spaceId);
    }

    /**
     * 查询文档空间管理列表
     *
     * @param docSpace 文档空间管理
     * @return 文档空间管理
     */
    @Override
    public List<DocSpace> selectDocSpaceList(DocSpace docSpace) {
        return docSpaceMapper.selectDocSpaceList(docSpace);
    }

    /**
     * 新增文档空间管理
     *
     * @param docSpace 文档空间管理
     * @return 结果
     */
    @Override
    public int insertDocSpace(DocSpace docSpace) {
        docSpace.setCreateTime(DateUtils.getNowDate());
        return docSpaceMapper.insertDocSpace(docSpace);
    }

    /**
     * 修改文档空间管理
     *
     * @param docSpace 文档空间管理
     * @return 结果
     */
    @Override
    public int updateDocSpace(DocSpace docSpace) {
        docSpace.setUpdateTime(DateUtils.getNowDate());
        return docSpaceMapper.updateDocSpace(docSpace);
    }

    /**
     * 批量删除文档空间管理
     *
     * @param spaceIds 需要删除的文档空间管理主键
     * @return 结果
     */
    @Override
    public int deleteDocSpaceBySpaceIds(Long[] spaceIds) {
        return docSpaceMapper.deleteDocSpaceBySpaceIds(spaceIds);
    }

    /**
     * 删除文档空间管理信息
     *
     * @param spaceId 文档空间管理主键
     * @return 结果
     */
    @Override
    public int deleteDocSpaceBySpaceId(Long spaceId) {
        return docSpaceMapper.deleteDocSpaceBySpaceId(spaceId);
    }
}
